"use strict";

var _interopRequireWildcard = require("reshow-runtime/helpers/interopRequireWildcard");

var _chai = require("chai");

var _Storage = _interopRequireWildcard(require("../Storage.js"));

var _reshowConstant = require("reshow-constant");

var fakeSetter = function fakeSetter(store) {
  return function (key) {
    return function (value) {
      if (_reshowConstant.UNDEFINED === typeof value) {
        return store[key];
      } else {
        if (null == value) {
          return delete store[key];
        } else {
          store[key] = value;
        }
      }
    };
  };
};

describe("Storage", function () {
  it("Storage / parseField", function () {
    var s = "10,abcdefghij";

    var _parseField = (0, _Storage.parseField)(s),
        len = _parseField[0],
        val = _parseField[1];

    (0, _chai.expect)(len).to.equal(10);
    (0, _chai.expect)(val).to.equal("abcdefghij");
  });
  it("Storage / encode, decode", function () {
    var o = {
      foo: "bar"
    };
    var sEncode = (0, _Storage.encode)(o);
    (0, _chai.expect)(sEncode).to.equal('13,{"foo":"bar"}');
    (0, _chai.expect)((0, _Storage.decode)(sEncode)).to.deep.equal(o);
  });
  it("test storage / set, get", function () {
    var fakeStore = {};
    var fakeStorage = new _Storage["default"](fakeSetter(fakeStore));
    var foo = fakeStorage.get('foo');
    (0, _chai.expect)(foo).to.be.undefined;
    foo = fakeStorage.set('foo', 'bar');
    (0, _chai.expect)(fakeStore).to.deep.equal({
      foo: '5,"bar"'
    });
    (0, _chai.expect)(foo.get('foo')).to.equal("bar");
  });
  it("test merge / merge same value", function () {
    var fakeStore = {};
    var fakeStorage = new _Storage["default"](fakeSetter(fakeStore));
    var result = fakeStorage.merge({
      foo: "bar"
    });
    (0, _chai.expect)(result.get('foo')).to.equal("bar");
    var result2 = result.merge({
      foo: "bar"
    });
    (0, _chai.expect)(result === result2).to.be["true"];
  });
  it("test merge / merge different value", function () {
    var fakeStore = {};
    var fakeStorage = new _Storage["default"](fakeSetter(fakeStore));
    var result = fakeStorage.merge({
      foo: "bar"
    });
    (0, _chai.expect)(result.get('foo')).to.equal("bar");
    var result2 = result.merge({
      foo: "bar1"
    });
    (0, _chai.expect)(result === result2).to.be["false"];
  });
});